==> elasticsearch-java-7.15.1-sources.jar: co/elastic/clients/elasticsearch/_types/analysis/NormalizerBuilders.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types.analysis;

/**
 * Builders for {@link Normalizer} variants.
 */
public class NormalizerBuilders {
	private NormalizerBuilders() {
	}

	/**
	 * Creates a builder for the {@link CustomNormalizer custom} {@code Normalizer}
	 * variant.
	 */
	public static CustomNormalizer.Builder custom() {
		return new CustomNormalizer.Builder();
	}

	/**
	 * Creates a builder for the {@link LowercaseNormalizer lowercase}
	 * {@code Normalizer} variant.
	 */
	public static LowercaseNormalizer.Builder lowercase() {
		return new LowercaseNormalizer.Builder();
	}

}

==> elasticsearch-java-8.12.1-sources.jar: co/elastic/clients/elasticsearch/_types/analysis/NormalizerBuilders.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types.analysis;

import co.elastic.clients.util.ObjectBuilder;
import java.util.function.Function;

/**
 * Builders for {@link Normalizer} variants.
 */
public class NormalizerBuilders {
	private NormalizerBuilders() {
	}

	/**
	 * Creates a builder for the {@link CustomNormalizer custom} {@code Normalizer}
	 * variant.
	 */
	public static CustomNormalizer.Builder custom() {
		return new CustomNormalizer.Builder();
	}

	/**
	 * Creates a Normalizer of the {@link CustomNormalizer custom}
	 * {@code Normalizer} variant.
	 */
	public static Normalizer custom(Function<CustomNormalizer.Builder, ObjectBuilder<CustomNormalizer>> fn) {
		Normalizer.Builder builder = new Normalizer.Builder();
		builder.custom(fn.apply(new CustomNormalizer.Builder()).build());
		return builder.build();
	}

	/**
	 * Creates a builder for the {@link LowercaseNormalizer lowercase}
	 * {@code Normalizer} variant.
	 */
	public static LowercaseNormalizer.Builder lowercase() {
		return new LowercaseNormalizer.Builder();
	}

	/**
	 * Creates a Normalizer of the {@link LowercaseNormalizer lowercase}
	 * {@code Normalizer} variant.
	 */
	public static Normalizer lowercase(Function<LowercaseNormalizer.Builder, ObjectBuilder<LowercaseNormalizer>> fn) {
		Normalizer.Builder builder = new Normalizer.Builder();
		builder.lowercase(fn.apply(new LowercaseNormalizer.Builder()).build());
		return builder.build();
	}

}
